@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Prepender;
 # ABSTRACT: prepend lines at the top of your perl files
-$Dist::Zilla::Plugin::Prepender::VERSION = '2.001';
+$Dist::Zilla::Plugin::Prepender::VERSION = '2.002';
 use Moose;
 use MooseX::Has::Sugar;
 
@@ -49,7 +49,7 @@ sub munge_file {
         return if $file->name =~ $skip;
     }
 
-    if ($file->does('Dist::Zilla:Role::MutableFile'))
+    if (not $file->does('Dist::Zilla::Role::MutableFile'))
     {
         $self->log_debug($file->name . ' is not a mutable type, skipping...');
         return;
@@ -124,7 +124,7 @@ Dist::Zilla::Plugin::Prepender - prepend lines at the top of your perl files
 
 =head1 VERSION
 
-version 2.001
+version 2.002
 
 =head1 SYNOPSIS
 
